@@ -182,8 +182,10 @@ void KonqPopupMenuTest::testFile()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("openInNewWindow") << QStringLiteral("openInNewTab") << QStringLiteral("separator")
-                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("rename") << QStringLiteral("trash") << QStringLiteral("separator")
+                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("rename") << QStringLiteral("trash")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview1");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("moveTo_submenu") << QStringLiteral("separator");
@@ -222,8 +224,10 @@ void KonqPopupMenuTest::testFileInReadOnlyDirectory()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("openInNewWindow") << QStringLiteral("openInNewTab") << QStringLiteral("separator")
-                    << QStringLiteral("copy") << QStringLiteral("separator")
+                    << QStringLiteral("copy")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview1");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("separator");
@@ -255,8 +259,10 @@ void KonqPopupMenuTest::testFilePreviewSubMenu()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("openInNewWindow") << QStringLiteral("openInNewTab") << QStringLiteral("separator")
-                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("rename") << QStringLiteral("trash") << QStringLiteral("separator")
+                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("rename") << QStringLiteral("trash")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("moveTo_submenu") << QStringLiteral("separator");
@@ -287,8 +293,9 @@ void KonqPopupMenuTest::testSubDirectory()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("openInNewWindow") << QStringLiteral("openInNewTab") << QStringLiteral("separator")
-                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("pasteto") << QStringLiteral("rename") << QStringLiteral("trash") << QStringLiteral("separator")
+                    << QStringLiteral("cut") << QStringLiteral("copy") << QStringLiteral("pasteto") << QStringLiteral("rename") << QStringLiteral("trash")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("moveTo_submenu") << QStringLiteral("separator");
@@ -319,8 +326,9 @@ void KonqPopupMenuTest::testViewDirectory()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("newmenu") << QStringLiteral("separator")
-                    << QStringLiteral("paste") << QStringLiteral("separator")
+                    << QStringLiteral("paste")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("moveTo_submenu") << QStringLiteral("separator");
@@ -353,6 +361,7 @@ void KonqPopupMenuTest::testViewReadOnlyDirectory()
     QStringList expectedActions;
     expectedActions // << "paste" // no paste since readonly
                     << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu");
     expectedActions << QStringLiteral("separator");
     expectedActions << QStringLiteral("copyTo_submenu") << QStringLiteral("separator"); // no moveTo_submenu, since readonly
@@ -385,8 +394,9 @@ void KonqPopupMenuTest::testHtmlLink()
     QStringList expectedActions;
     expectedActions << QStringLiteral("openInNewWindow") << QStringLiteral("openInNewTab") << QStringLiteral("separator")
                     << QStringLiteral("bookmark_add") << QStringLiteral("savelinkas") << QStringLiteral("copylinklocation")
-                    << QStringLiteral("separator")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu")
                     << QStringLiteral("separator")
                     << QStringLiteral("viewDocumentSource");
@@ -424,8 +434,9 @@ void KonqPopupMenuTest::testHtmlPage()
     qDebug() << actions;
     QStringList expectedActions;
     expectedActions << QStringLiteral("bookmark_add")
-                    << QStringLiteral("separator")
                     << QStringLiteral("openwith")
+                    << QStringLiteral("openwith")
+                    << QStringLiteral("separator")
                     << QStringLiteral("preview_submenu")
                     << QStringLiteral("separator")
                     // << TODO "stopanimations"
