@@ -21,8 +21,9 @@
 #ifndef KONQUERORADAPTOR_H
 #define KONQUERORADAPTOR_H
 
-#include <QtCore/QStringList>
-#include <QtDBus/QtDBus>
+#include <QStringList>
+#include <QDBusObjectPath>
+#include <QDBusMessage>
 
 #define KONQ_MAIN_PATH "/KonqMain"
 
