@@ -23,7 +23,7 @@
  */
 
 #include "webenginepart.h"
-#include "webengineparthtmlmimetypehandler.h"
+#include "webenginepartkiohandler.h"
 
 //#include <QWebHistoryItem>
 #include <QWebEngineSettings>
@@ -37,6 +37,7 @@
 #include "webhistoryinterface.h"
 #include "webenginewallet.h"
 #include "webengineparterrorschemehandler.h"
+#include "webenginepartcookiejar.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -74,7 +75,6 @@
 #include <QMenu>
 #include <QStatusBar>
 #include "utils.h"
-#include <QWebEngineProfile>
 
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
                          const QByteArray& cachedHistory, const QStringList& /*args*/)
@@ -91,7 +91,9 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
     if (!prof->urlSchemeHandler("error")) {
         prof->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(prof));
+        prof->installUrlSchemeHandler("help", new WebEnginePartKIOHandler(prof));
     }
+    static WebEnginePartCookieJar s_cookieJar(prof, prof);
     KAboutData about = KAboutData(QStringLiteral("webenginepart"),
                                   i18nc("Program Name", "WebEnginePart"),
                                   /*version*/ QStringLiteral("1.3.0"),
@@ -155,7 +157,7 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     // Set the part's widget
     setWidget(mainWidget);
 
-    // Set the web view as the the focus object
+    // Set the web view as the focus object
     mainWidget->setFocusProxy(m_webView);
 
     // Connect the signals from the webview
@@ -349,7 +351,7 @@ void WebEnginePart::attemptInstallKIOSchemeHandler(const QUrl& url)
         QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
         QByteArray scheme = url.scheme().toUtf8();
         if (!prof->urlSchemeHandler(scheme)) {
-            prof->installUrlSchemeHandler(scheme, new WebEnginePartHtmlMimetypeHandler(prof));
+            prof->installUrlSchemeHandler(scheme, new WebEnginePartKIOHandler(prof));
         }
     }
 
@@ -399,6 +401,7 @@ bool WebEnginePart::openUrl(const QUrl &_u)
     // Set URL in KParts before emitting started; konq plugins rely on that.
     setUrl(u);
     m_doLoadFinishedActions = true;
+    page()->setLoadUrlCalledByPart(u);
     m_webView->loadUrl(u, args, bargs);
     return true;
 }
